==> zio-aws-wafregional_3-5.17.113.1-sources.jar: zio/aws/wafregional/model/GetByteMatchSetResponse.scala <==
package zio.aws.wafregional.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetByteMatchSetResponse(
    byteMatchSet: Option[zio.aws.wafregional.model.ByteMatchSet] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse = {
    import GetByteMatchSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
      .builder()
      .optionallyWith(byteMatchSet.map(value => value.buildAwsValue()))(
        _.byteMatchSet
      )
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.GetByteMatchSetResponse.ReadOnly =
    zio.aws.wafregional.model.GetByteMatchSetResponse.wrap(buildAwsValue())
}
object GetByteMatchSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.GetByteMatchSetResponse =
      zio.aws.wafregional.model
        .GetByteMatchSetResponse(byteMatchSet.map(value => value.asEditable))
    def byteMatchSet: Option[zio.aws.wafregional.model.ByteMatchSet.ReadOnly]
    def getByteMatchSet
        : ZIO[Any, AwsError, zio.aws.wafregional.model.ByteMatchSet.ReadOnly] =
      AwsError.unwrapOptionField("byteMatchSet", byteMatchSet)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
  ) extends zio.aws.wafregional.model.GetByteMatchSetResponse.ReadOnly {
    override val byteMatchSet
        : Option[zio.aws.wafregional.model.ByteMatchSet.ReadOnly] = scala
      .Option(impl.byteMatchSet())
      .map(value => zio.aws.wafregional.model.ByteMatchSet.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
  ): zio.aws.wafregional.model.GetByteMatchSetResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-wafregional_3-5.17.169.1-sources.jar: zio/aws/wafregional/model/GetByteMatchSetResponse.scala <==
package zio.aws.wafregional.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetByteMatchSetResponse(
    byteMatchSet: Optional[zio.aws.wafregional.model.ByteMatchSet] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse = {
    import GetByteMatchSetResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
      .builder()
      .optionallyWith(byteMatchSet.map(value => value.buildAwsValue()))(
        _.byteMatchSet
      )
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.GetByteMatchSetResponse.ReadOnly =
    zio.aws.wafregional.model.GetByteMatchSetResponse.wrap(buildAwsValue())
}
object GetByteMatchSetResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.GetByteMatchSetResponse =
      zio.aws.wafregional.model
        .GetByteMatchSetResponse(byteMatchSet.map(value => value.asEditable))
    def byteMatchSet: Optional[zio.aws.wafregional.model.ByteMatchSet.ReadOnly]
    def getByteMatchSet
        : ZIO[Any, AwsError, zio.aws.wafregional.model.ByteMatchSet.ReadOnly] =
      AwsError.unwrapOptionField("byteMatchSet", byteMatchSet)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
  ) extends zio.aws.wafregional.model.GetByteMatchSetResponse.ReadOnly {
    override val byteMatchSet
        : Optional[zio.aws.wafregional.model.ByteMatchSet.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.byteMatchSet())
        .map(value => zio.aws.wafregional.model.ByteMatchSet.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.GetByteMatchSetResponse
  ): zio.aws.wafregional.model.GetByteMatchSetResponse.ReadOnly = new Wrapper(
    impl
  )
}
